@@ -3,11 +3,12 @@
 viledatools
 """
 
-__version__ = "1.0.28"
+__version__ = "1.0.31"
 
 from typing import Tuple
 
-from .apiutils import (FARequests as FARequests, fagetrefs as fagetrefs, getcookieval as getcookieval, gettag as gettag)
+from .apiutils import (FARequests as FARequests, fagetrefs as fagetrefs, getcookieval as getcookieval,
+                       gettag as gettag, make_search_string as make_search_string)
 from .diagonaltablewalk import DiagonalTableWalk as DiagonalTableWalk
 from .fatask import FATask as FATask
 from .importcellparser import ImportCellParser as ImportCellParser
@@ -18,6 +19,7 @@ from .viledautils import ViledaUtils as ViledaUtils
 
 __all__: Tuple[str, ...] = (
         "fagetrefs",
+        "make_search_string",
         "FARequests",
         "getcookieval",
         "gettag",
